From dfb74f84549fb0a8debbc85be457301237e8c3e3 Mon Sep 17 00:00:00 2001
From: Campbell Barton <ideasman42@gmail.com>
Date: Mon, 17 Oct 2011 06:59:42 +0000
Subject: [PATCH] fix spelling errors for comments

---
 io_curve_svg/import_svg.py         |  2 +-
 io_import_scene_lwo.py             |  2 +-
 io_mesh_ply/export_ply.py          |  2 +-
 io_mesh_uv_layout/__init__.py      |  2 +-
 io_mesh_uv_layout/export_uv_png.py |  2 +-
 io_scene_3ds/import_3ds.py         |  2 +-
 io_scene_fbx/export_fbx.py         | 28 ++++++++++++++--------------
 io_scene_obj/export_obj.py         |  2 +-
 io_scene_obj/import_obj.py         |  4 ++--
 io_scene_x3d/import_x3d.py         | 24 ++++++++++++------------
 object_fracture/fracture_ops.py    |  2 +-
 object_grease_scatter.py           |  2 +-
 system_demo_mode/__init__.py       |  2 +-
 system_demo_mode/config.py         |  2 +-
 system_property_chart.py           |  4 ++--
 15 files changed, 41 insertions(+), 41 deletions(-)

diff --git a/io_curve_svg/import_svg.py b/io_curve_svg/import_svg.py
index 04ce6b086..56ca68a69 100644
--- a/io_curve_svg/import_svg.py
+++ b/io_curve_svg/import_svg.py
@@ -155,7 +155,7 @@ def SVGParseCoord(coord, size):
 
     token, last_char = SVGParseFloat(coord)
     val = float(token)
-    unit = coord[last_char:].strip()  # strip() incase there is a space
+    unit = coord[last_char:].strip()  # strip() in case there is a space
 
     if unit == '%':
         return float(size) / 100.0 * val
diff --git a/io_import_scene_lwo.py b/io_import_scene_lwo.py
index 87c400304..6e7a3abd6 100644
--- a/io_import_scene_lwo.py
+++ b/io_import_scene_lwo.py
@@ -1027,7 +1027,7 @@ def build_objects(object_layers, object_surfs, object_tags, object_name, add_sub
         # faster, would be faster again to use an array
         me.vertices.foreach_set("co", [axis for co in layer_data.pnts for axis in co])
 
-        ngons= {}   # To keep the FaceIdx consistant, handle NGons later.
+        ngons= {}   # To keep the FaceIdx consistent, handle NGons later.
         edges= []   # Holds the FaceIdx of the 2-point polys.
         for fi, fpol in enumerate(layer_data.pols):
             fpol.reverse()   # Reversing gives correct normal directions
diff --git a/io_mesh_ply/export_ply.py b/io_mesh_ply/export_ply.py
index b02dd1395..84d9a45ca 100644
--- a/io_mesh_ply/export_ply.py
+++ b/io_mesh_ply/export_ply.py
@@ -98,7 +98,7 @@ def save(operator,
         else:
             active_col_layer = active_col_layer.data
 
-    # incase
+    # in case
     color = uvcoord = uvcoord_key = normal = normal_key = None
 
     mesh_verts = mesh.vertices  # save a lookup
diff --git a/io_mesh_uv_layout/__init__.py b/io_mesh_uv_layout/__init__.py
index ac650976b..dd4fc2ad3 100644
--- a/io_mesh_uv_layout/__init__.py
+++ b/io_mesh_uv_layout/__init__.py
@@ -125,7 +125,7 @@ class ExportUVLayout(bpy.types.Operator):
             image = space_data.image
             if image:
                 width, height = tuple(context.space_data.image.size)
-                # incase no data is found.
+                # in case no data is found.
                 if width and height:
                     image_width, image_height = width, height
 
diff --git a/io_mesh_uv_layout/export_uv_png.py b/io_mesh_uv_layout/export_uv_png.py
index ec92c4d8a..579243582 100644
--- a/io_mesh_uv_layout/export_uv_png.py
+++ b/io_mesh_uv_layout/export_uv_png.py
@@ -39,7 +39,7 @@ def write(fw, mesh_source, image_width, image_height, opacity, face_iter_func):
 
     faces_source = mesh_source.faces
 
-    # get unique UV's incase there are many overlapping which slow down filling.
+    # get unique UV's in case there are many overlapping which slow down filling.
     face_hash_3 = set()
     face_hash_4 = set()
     for i, uv in face_iter_func():
diff --git a/io_scene_3ds/import_3ds.py b/io_scene_3ds/import_3ds.py
index a94c7092f..73f186018 100644
--- a/io_scene_3ds/import_3ds.py
+++ b/io_scene_3ds/import_3ds.py
@@ -813,7 +813,7 @@ def load_3ds(filepath,
 
     ##IMAGE_SEARCH
 
-    # fixme, make unglobal, clear incase
+    # fixme, make unglobal, clear in case
     object_dictionary.clear()
     object_matrix.clear()
 
diff --git a/io_scene_fbx/export_fbx.py b/io_scene_fbx/export_fbx.py
index f644603a4..e217f1cf3 100644
--- a/io_scene_fbx/export_fbx.py
+++ b/io_scene_fbx/export_fbx.py
@@ -264,13 +264,13 @@ def save_single(operator, scene, filepath="",
 
             self.blenName = blenBone.name
             self.blenBone = blenBone
-            self.blenMeshes = {}					# fbxMeshObName : mesh
+            self.blenMeshes = {}  # fbxMeshObName : mesh
             self.fbxArm = fbxArm
             self.restMatrix = blenBone.matrix_local
 
             # not used yet
-            # self.restMatrixInv =	self.restMatrix.inverted()
-            # self.restMatrixLocal =	None # set later, need parent matrix
+            #~ self.restMatrixInv = self.restMatrix.inverted()
+            #~ self.restMatrixLocal = None # set later, need parent matrix
 
             self.parent = None
 
@@ -278,7 +278,7 @@ def save_single(operator, scene, filepath="",
             pose = fbxArm.blenObject.pose
             self.__pose_bone = pose.bones[self.blenName]
 
-            # store a list if matricies here, (poseMatrix, head, tail)
+            # store a list if matrices here, (poseMatrix, head, tail)
             # {frame:posematrix, frame:posematrix, ...}
             self.__anim_poselist = {}
 
@@ -451,12 +451,12 @@ def save_single(operator, scene, filepath="",
     fw('\nCreationTime: "%.4i-%.2i-%.2i %.2i:%.2i:%.2i:000"' % curtime)
     fw('\nCreator: "Blender version %s"' % bpy.app.version_string)
 
-    pose_items = []  # list of (fbxName, matrix) to write pose data for, easier to collect allong the way
+    pose_items = []  # list of (fbxName, matrix) to write pose data for, easier to collect along the way
 
     # --------------- funcs for exporting
     def object_tx(ob, loc, matrix, matrix_mod=None):
         '''
-        Matrix mod is so armature objects can modify their bone matricies
+        Matrix mod is so armature objects can modify their bone matrices
         '''
         if isinstance(ob, bpy.types.Bone):
 
@@ -556,7 +556,7 @@ def save_single(operator, scene, filepath="",
                     constraint_values["sca_max"] = constraint.max_x, constraint.max_y, constraint.max_z
                     constraint_values["sca_limit"] = constraint.use_min_x, constraint.use_min_y, constraint.use_min_z, constraint.use_max_x, constraint.use_max_y, constraint.use_max_z
 
-        # incase bad values are assigned.
+        # in case bad values are assigned.
         assert(len(constraint_values) == 9)
 
         return constraint_values
@@ -675,8 +675,8 @@ def save_single(operator, scene, filepath="",
         fw('\n\tModel: "Model::%s", "Limb" {' % my_bone.fbxName)
         fw('\n\t\tVersion: 232')
 
-        #poseMatrix = write_object_props(my_bone.blenBone, None, None, my_bone.fbxArm.parRelMatrix())[3]
-        poseMatrix = write_object_props(my_bone.blenBone, pose_bone=my_bone.getPoseBone())[3]  # dont apply bone matricies anymore
+        #~ poseMatrix = write_object_props(my_bone.blenBone, None, None, my_bone.fbxArm.parRelMatrix())[3]
+        poseMatrix = write_object_props(my_bone.blenBone, pose_bone=my_bone.getPoseBone())[3]  # dont apply bone matrices anymore
         pose_items.append((my_bone.fbxName, poseMatrix))
 
         # fw('\n\t\t\tProperty: "Size", "double", "",%.6f' % ((my_bone.blenData.head['ARMATURESPACE'] - my_bone.blenData.tail['ARMATURESPACE']) * my_bone.fbxArm.parRelMatrix()).length)
@@ -1252,7 +1252,7 @@ def save_single(operator, scene, filepath="",
     def write_sub_deformer_skin(my_mesh, my_bone, weights):
 
         '''
-        Each subdeformer is spesific to a mesh, but the bone it links to can be used by many sub-deformers
+        Each subdeformer is specific to a mesh, but the bone it links to can be used by many sub-deformers
         So the SubDeformer needs the mesh-object name as a prefix to make it unique
 
         Its possible that there is no matching vgroup in this mesh, in that case no verts are in the subdeformer,
@@ -1896,7 +1896,7 @@ def save_single(operator, scene, filepath="",
     materials = {}  # (mat, image) keys, should be a set()
     textures = {}  # should be a set()
 
-    tmp_ob_type = None  # incase no objects are exported, so as not to raise an error
+    tmp_ob_type = None  # in case no objects are exported, so as not to raise an error
 
 ## XXX
 
@@ -2601,7 +2601,7 @@ Connections:  {''')
                         tagged_actions.append(action.name)
                         tmp_act_count += 1
 
-                        # incase there are no actions applied to armatures
+                        # in case there are no actions applied to armatures
                         # for example, when a user deletes the current action.
                         action_lastcompat = action
 
@@ -2667,7 +2667,7 @@ Takes:  {''')
 		;----------------------------------------------------''')
 
             # set pose data for all bones
-            # do this here incase the action changes
+            # do this here in case the action changes
             '''
             for my_bone in ob_bones:
                 my_bone.flushAnimData()
@@ -2817,7 +2817,7 @@ Takes:  {''')
             fw('\n\t}')
 
             # end action loop. set original actions
-            # do this after every loop incase actions effect eachother.
+            # do this after every loop in case actions effect eachother.
             for my_arm in ob_arms:
                 if my_arm.blenObject.animation_data:
                     my_arm.blenObject.animation_data.action = my_arm.blenAction
diff --git a/io_scene_obj/export_obj.py b/io_scene_obj/export_obj.py
index 6d00bb42f..d1b3918da 100644
--- a/io_scene_obj/export_obj.py
+++ b/io_scene_obj/export_obj.py
@@ -406,7 +406,7 @@ def write_file(filepath, objects, scene,
 
             # UV
             if faceuv:
-                # incase removing some of these dont get defined.
+                # in case removing some of these dont get defined.
                 uv = uvkey = uv_dict = f_index = uv_index = None
 
                 uv_face_mapping = [[0, 0, 0, 0] for i in range(len(face_index_pairs))]  # a bit of a waste for tri's :/
diff --git a/io_scene_x3d/import_x3d.py b/io_scene_x3d/import_x3d.py
index 660d10227..15ee3a4b9 100644
--- a/io_scene_x3d/import_x3d.py
+++ b/io_scene_x3d/import_x3d.py
@@ -532,7 +532,7 @@ class vrmlNode(object):
         return results
 
     def getFieldName(self, field, ancestry, AS_CHILD=False):
-        self_real = self.getRealNode()  # incase we're an instance
+        self_real = self.getRealNode()  # in case we're an instance
 
         for f in self_real.fields:
             # print(f)
@@ -608,7 +608,7 @@ class vrmlNode(object):
         return None
 
     def getFieldAsInt(self, field, default, ancestry):
-        self_real = self.getRealNode()  # incase we're an instance
+        self_real = self.getRealNode()  # in case we're an instance
 
         f = self_real.getFieldName(field, ancestry)
         if f is None:
@@ -627,7 +627,7 @@ class vrmlNode(object):
             return default
 
     def getFieldAsFloat(self, field, default, ancestry):
-        self_real = self.getRealNode()  # incase we're an instance
+        self_real = self.getRealNode()  # in case we're an instance
 
         f = self_real.getFieldName(field, ancestry)
         if f is None:
@@ -646,7 +646,7 @@ class vrmlNode(object):
             return default
 
     def getFieldAsFloatTuple(self, field, default, ancestry):
-        self_real = self.getRealNode()  # incase we're an instance
+        self_real = self.getRealNode()  # in case we're an instance
 
         f = self_real.getFieldName(field, ancestry)
         if f is None:
@@ -673,7 +673,7 @@ class vrmlNode(object):
             return default
 
     def getFieldAsBool(self, field, default, ancestry):
-        self_real = self.getRealNode()  # incase we're an instance
+        self_real = self.getRealNode()  # in case we're an instance
 
         f = self_real.getFieldName(field, ancestry)
         if f is None:
@@ -694,7 +694,7 @@ class vrmlNode(object):
             return default
 
     def getFieldAsString(self, field, default, ancestry):
-        self_real = self.getRealNode()  # incase we're an instance
+        self_real = self.getRealNode()  # in case we're an instance
 
         f = self_real.getFieldName(field, ancestry)
         if f is None:
@@ -736,7 +736,7 @@ class vrmlNode(object):
 
             return array_data
 
-        self_real = self.getRealNode()  # incase we're an instance
+        self_real = self.getRealNode()  # in case we're an instance
 
         child_array = self_real.getFieldName(field, ancestry, True)
 
@@ -781,7 +781,7 @@ class vrmlNode(object):
 
         # make a flat array
         if flat:
-            flat_array = array_data  # we are alredy flat.
+            flat_array = array_data  # we are already flat.
         else:
             flat_array = []
 
@@ -816,7 +816,7 @@ class vrmlNode(object):
         '''
         Get a list of strings
         '''
-        self_real = self.getRealNode()  # incase we're an instance
+        self_real = self.getRealNode()  # in case we're an instance
 
         child_array = None
         for child in self_real.children:
@@ -1277,7 +1277,7 @@ def vrml_parse(path):
     lines.append('}')
 
     root = vrmlNode(None, NODE_NORMAL, -1)
-    root.setRoot(path)  # we need to set the root so we have a namespace and know the path incase of inlineing
+    root.setRoot(path)  # we need to set the root so we have a namespace and know the path in case of inlineing
 
     # Parse recursively
     root.parse(0)
@@ -1345,12 +1345,12 @@ class x3dNode(vrmlNode):
     def getFieldName(self, field, ancestry, AS_CHILD=False):
         # ancestry and AS_CHILD are ignored, only used for VRML now
 
-        self_real = self.getRealNode()  # incase we're an instance
+        self_real = self.getRealNode()  # in case we're an instance
         field_xml = self.x3dNode.getAttributeNode(field)
         if field_xml:
             value = field_xml.value
 
-            # We may want to edit. for x3d spesific stuff
+            # We may want to edit. for x3d specific stuff
             # Sucks a bit to return the field name in the list but vrml excepts this :/
             return value.split()
         else:
diff --git a/object_fracture/fracture_ops.py b/object_fracture/fracture_ops.py
index 2878fd203..d04a3b922 100644
--- a/object_fracture/fracture_ops.py
+++ b/object_fracture/fracture_ops.py
@@ -359,7 +359,7 @@ class FractureSimple(bpy.types.Operator):
         default=False)
 
     hierarchy = BoolProperty(name="Generate hierarchy",
-        description="Hierarchy is usefull for simulation of objects" \
+        description="Hierarchy is useful for simulation of objects" \
                     " breaking in motion",
         default=False)
 
diff --git a/object_grease_scatter.py b/object_grease_scatter.py
index 71d06584a..acb2c14c2 100644
--- a/object_grease_scatter.py
+++ b/object_grease_scatter.py
@@ -211,7 +211,7 @@ def _main(self,
                     continue
                 if n_other:
                     # cast vectors twice as long as the distance
-                    # needed just incase.
+                    # needed just in case.
                     n_down = (n * -SEEK)
                     l = n_down.length
                     n_other.length = l
diff --git a/system_demo_mode/__init__.py b/system_demo_mode/__init__.py
index e17b8e842..5602358c1 100644
--- a/system_demo_mode/__init__.py
+++ b/system_demo_mode/__init__.py
@@ -70,7 +70,7 @@ class DemoModeSetup(bpy.types.Operator):
     # ====
     anim_cycles = IntProperty(name="Cycles", description="Number of times to play the animation", min=1, max=1000, default=2)
     anim_time_min = FloatProperty(name="Time Min", description="Minimum number of seconds to show the animation for (for small loops)", min=0.0, max=1000.0, soft_min=1.0, soft_max=1000.0, default=4.0)
-    anim_time_max = FloatProperty(name="Time Max", description="Maximum number of seconds to show the animation for (incase the end frame is very high for no reason)", min=0.0, max=100000000.0, soft_min=1.0, soft_max=100000000.0, default=8.0)
+    anim_time_max = FloatProperty(name="Time Max", description="Maximum number of seconds to show the animation for (in case the end frame is very high for no reason)", min=0.0, max=100000000.0, soft_min=1.0, soft_max=100000000.0, default=8.0)
     anim_screen_switch = FloatProperty(name="Screen Switch", description="Time between switching screens (in seconds) or 0 to disable", min=0.0, max=100000000.0, soft_min=1.0, soft_max=60.0, default=0.0)
     #
     # render
diff --git a/system_demo_mode/config.py b/system_demo_mode/config.py
index d39daae12..6f31fbe8b 100644
--- a/system_demo_mode/config.py
+++ b/system_demo_mode/config.py
@@ -16,7 +16,7 @@ def blend_list(path):
 
 def generate(dirpath, random_order, **kwargs):
 
-    # incase file is selected!
+    # in case file is selected!
     if not os.path.exists(dirpath) or not os.path.isdir(dirpath):
         dirpath = os.path.dirname(dirpath)
 
diff --git a/system_property_chart.py b/system_property_chart.py
index 8226a698c..8533ad362 100644
--- a/system_property_chart.py
+++ b/system_property_chart.py
@@ -69,7 +69,7 @@ def _property_chart_draw(self, context):
     except ValueError:
         active_index = -1
 
-    if active_index > 0:  # not the first alredy
+    if active_index > 0:  # not the first already
         selected_objects[0], selected_objects[active_index] = selected_objects[active_index], selected_objects[0]
 
     id_storage = context.scene
@@ -192,7 +192,7 @@ def _property_chart_copy(self, context):
             try:
                 exec("obj_iter.%s = obj.%s" % (data_path, data_path))
             except:
-                # just incase we need to know what went wrong!
+                # just in case we need to know what went wrong!
                 import traceback
                 traceback.print_exc()
 
diff --git a/io_scene_obj/import_obj.py b/io_scene_obj/import_obj.py
index 1f7ab9b78..02e8dfdb4 100644
--- a/io_scene_obj/import_obj.py
+++ b/io_scene_obj/import_obj.py
@@ -804,7 +804,7 @@ def get_float_func(filepath):
                 return float
 
     file.close()
     # incase all vert values were ints
     return float
 
 
@@ -1021,7 +1021,7 @@ def load(operator, context, filepath,
         elif line.startswith(b'curv ') or context_multi_line == b'curv':
             line_split = line.split()
 
-            curv_idx = context_nurbs[b'curv_idx'] = context_nurbs.get(b'curv_idx', [])  # incase were multiline
+            curv_idx = context_nurbs[b'curv_idx'] = context_nurbs.get(b'curv_idx', [])  # in case were multiline
 
             if not context_multi_line:
                 context_nurbs[b'curv_range'] = float_func(line_split[1]), float_func(line_split[2])
@@ -804,7 +804,7 @@ def get_float_func(filepath):
 
     file.close()
-    # incase all vert values were ints
+    # in case all vert values were ints
     return float
 
-- 
GitLab